Dependency Injector Contributors
================================

+ Roman Mogilatov (rmk135)
+ Konstantin vz'One Enchant (sirkonst)
+ Terrence Brannon (metaperl)
+ Stanislav Lobanov (asyncee)
+ James Lafa (jameslafa)
